"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * react app preset
 * @author: sunkeysun
 */
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const packageMap = {
    env: '@babel/preset-env',
    typescript: '@babel/preset-typescript',
    react: '@babel/preset-react',
};
exports.default = (api, opts = {}, env = 'production') => {
    const isProduction = env === 'production';
    const { alias } = opts;
    function ifRequire(pkg, options = {}) {
        if (!pkg || opts[pkg] === false)
            return false;
        let packageName = pkg;
        if (Object.keys(packageMap).includes(pkg)) {
            packageName = packageMap[pkg];
        }
        return [
            require(packageName),
            (0, lodash_merge_1.default)(options, opts?.[pkg] ?? {}),
        ];
    }
    api.cache.using(() => env);
    return {
        presets: [
            ifRequire('env'),
            ifRequire('react', { runtime: 'automatic' }),
            ifRequire('typescript'),
        ].filter(Boolean),
        plugins: [
            ifRequire('@babel/plugin-proposal-decorators', { legacy: true }),
            ifRequire('@babel/plugin-proposal-export-default-from'),
            ifRequire('@babel/plugin-proposal-export-namespace-from'),
            ifRequire('@babel/plugin-transform-runtime', { regenerator: true }),
            ifRequire(isProduction && 'react-refresh/babel'),
            alias && [require('babel-plugin-module-resolver'), { alias }],
        ].filter(Boolean),
    };
};
